@@ -11,12 +11,15 @@ use Rose::HTMLx::Form::Field::Boolean;
 use Rose::HTMLx::Form::Field::Autocomplete;
 use Rose::HTMLx::Form::Field::Serial;
 use Rose::HTML::Form::Field::PopUpMenu;
+use Rose::HTMLx::Form::Field::PopUpMenuNumeric;
 
 __PACKAGE__->field_type_class(
     boolean => 'Rose::HTMLx::Form::Field::Boolean' );
 __PACKAGE__->field_type_class(
     autocomplete => 'Rose::HTMLx::Form::Field::Autocomplete' );
 __PACKAGE__->field_type_class( serial => 'Rose::HTMLx::Form::Field::Serial' );
+__PACKAGE__->field_type_class(
+    nummenu => 'Rose::HTMLx::Form::Field::PopUpMenuNumeric' );
 
 use Rose::Object::MakeMethods::Generic (
     'scalar --get_set_init' =>
@@ -24,7 +27,7 @@ use Rose::Object::MakeMethods::Generic (
 
 );
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =head1 NAME
 
@@ -297,7 +300,12 @@ sub _convert_field_to_menu {
 
     $self->debug and warn "$field_name converting to menu";
 
-    my $menu = Rose::HTML::Form::Field::PopUpMenu->new(
+    my $menu_class
+        = $field->isa('Rose::HTML::Form::Field::Numeric')
+        ? 'Rose::HTMLx::Form::Field::PopUpMenuNumeric'
+        : 'Rose::HTML::Form::Field::PopUpMenu';
+
+    my $menu = $menu_class->new(
         id       => $field->id,
         name     => $field_name,
         type     => 'menu',
